
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.17.1',
    'branch_nick': 'patch-0-1_17_1_preparation',
    'revision_id': 'e248b33faf762729778d8465e0093aab0529a08d',
    'revno': 6799
}
